[gnome-db] [PATCH] libgnomedb C++ compatibility



Hi there,

The attached patch fixes the use of "class" and "typename" as
identifiers in numerous headers.  They are reserved keywords in C++,
stopping libgnomedb being used in C++ programs.  It also adds a useless
definition of "enum _GnomeDbDataCellRendererInfoStatus".  This is used
in a typedef but never defined, which is apparently against a
C++ standard.

Regards,

Bob

-- 
Bob Ham <rah bash sh>
Index: libgnomedb/gnome-db-base.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-base.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-base.h
--- libgnomedb/gnome-db-base.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-base.h	1 Dec 2005 18:24:14 -0000
@@ -65,7 +65,7 @@ struct _GnomeDbBase
 /* struct for the object's class */
 struct _GnomeDbBaseClass
 {
-	GObjectClass            class;
+	GObjectClass            parent_class;
 
 	/* signals */
 	void        (*changed)        (GnomeDbBase *base);
Index: libgnomedb/gnome-db-condition.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-condition.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-condition.h
--- libgnomedb/gnome-db-condition.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-condition.h	1 Dec 2005 18:24:14 -0000
@@ -85,7 +85,7 @@ struct _GnomeDbCondition
 /* struct for the object's class */
 struct _GnomeDbConditionClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 };
 
 GType            gnome_db_condition_get_type                (void);
Index: libgnomedb/gnome-db-constraint.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-constraint.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-constraint.h
--- libgnomedb/gnome-db-constraint.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-constraint.h	1 Dec 2005 18:24:14 -0000
@@ -82,7 +82,7 @@ struct _GnomeDbConstraint
 /* struct for the object's class */
 struct _GnomeDbConstraintClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbConstraint *obj);
Index: libgnomedb/gnome-db-custom-layout.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-custom-layout.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-custom-layout.h
--- libgnomedb/gnome-db-custom-layout.h	11 Aug 2005 13:30:31 -0000	1.4
+++ libgnomedb/gnome-db-custom-layout.h	1 Dec 2005 18:24:14 -0000
@@ -99,7 +99,7 @@ struct _GnomeDbCustomLayout
 /* struct for the object's class */
 struct _GnomeDbCustomLayoutClass
 {
-	GnomeDbBaseClass          class;
+	GnomeDbBaseClass          parent_class;
 };
 
 GType               gnome_db_custom_layout_get_type                 (void);
Index: libgnomedb/gnome-db-data-proxy.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-data-proxy.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-data-proxy.h
--- libgnomedb/gnome-db-data-proxy.h	29 Jul 2005 13:05:48 -0000	1.4
+++ libgnomedb/gnome-db-data-proxy.h	1 Dec 2005 18:24:14 -0000
@@ -76,7 +76,7 @@ struct _GnomeDbDataProxy
 /* struct for the object's class */
 struct _GnomeDbDataProxyClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 };
 
 GType             gnome_db_data_proxy_get_type             (void);
Index: libgnomedb/gnome-db-data-set.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-data-set.h,v
retrieving revision 1.6
diff -u -p -r1.6 gnome-db-data-set.h
--- libgnomedb/gnome-db-data-set.h	29 Jul 2005 13:05:48 -0000	1.6
+++ libgnomedb/gnome-db-data-set.h	1 Dec 2005 18:24:14 -0000
@@ -91,7 +91,7 @@ struct _GnomeDbDataSet
 /* struct for the object's class */
 struct _GnomeDbDataSetClass
 {
-	GnomeDbBaseClass          class;
+	GnomeDbBaseClass          parent_class;
 
 	void               (*param_changed) (GnomeDbDataSet *dataset, GnomeDbParameter *param);
 };
Index: libgnomedb/gnome-db-database.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-database.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-database.h
--- libgnomedb/gnome-db-database.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-database.h	1 Dec 2005 18:24:14 -0000
@@ -61,7 +61,7 @@ struct _GnomeDbDatabase
 /* struct for the object's class */
 struct _GnomeDbDatabaseClass
 {
-	GnomeDbBaseClass class;
+	GnomeDbBaseClass parent_class;
 
 	/* signals */
 	void   (*table_added)               (GnomeDbDatabase *obj, GnomeDbTable *table);
Index: libgnomedb/gnome-db-dict.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-dict.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-dict.h
--- libgnomedb/gnome-db-dict.h	29 Jul 2005 13:05:48 -0000	1.4
+++ libgnomedb/gnome-db-dict.h	1 Dec 2005 18:24:14 -0000
@@ -61,7 +61,7 @@ struct _GnomeDbDict
 /* struct for the object's class */
 struct _GnomeDbDictClass
 {
-	GObjectClass            class;
+	GObjectClass            parent_class;
 
         /* signal the addition or removal of a query in the queries list */
         void (*query_added)      (GnomeDbDict * dict, GnomeDbQuery *new_query);
Index: libgnomedb/gnome-db-graphviz.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-graphviz.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-graphviz.h
--- libgnomedb/gnome-db-graphviz.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-graphviz.h	1 Dec 2005 18:24:14 -0000
@@ -56,7 +56,7 @@ struct _GnomeDbGraphviz
 /* struct for the object's class */
 struct _GnomeDbGraphvizClass
 {
-	GnomeDbBaseClass              class;
+	GnomeDbBaseClass              parent_class;
 };
 
 GType           gnome_db_graphviz_get_type         (void);
Index: libgnomedb/gnome-db-join.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-join.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-join.h
--- libgnomedb/gnome-db-join.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-join.h	1 Dec 2005 18:24:14 -0000
@@ -73,7 +73,7 @@ struct _GnomeDbJoin
 /* struct for the object's class */
 struct _GnomeDbJoinClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*type_changed)         (GnomeDbJoin *join);
Index: libgnomedb/gnome-db-layout.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-layout.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-layout.h
--- libgnomedb/gnome-db-layout.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-layout.h	1 Dec 2005 18:24:14 -0000
@@ -50,7 +50,7 @@ struct _GnomeDbLayout
 /* struct for the object's class */
 struct _GnomeDbLayoutClass
 {
-	GtkVBoxClass          class;
+	GtkVBoxClass          parent_class;
 };
 
 GType           gnome_db_layout_get_type                 (void);
Index: libgnomedb/gnome-db-model-wrapper.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-model-wrapper.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-model-wrapper.h
--- libgnomedb/gnome-db-model-wrapper.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-model-wrapper.h	1 Dec 2005 18:24:14 -0000
@@ -45,7 +45,7 @@ struct _GnomeDbModelWrapper
 /* struct for the object's class */
 struct _GnomeDbModelWrapperClass
 {
-	GnomeDbBaseClass             class;
+	GnomeDbBaseClass             parent_class;
 };
 
 GType           gnome_db_model_wrapper_get_type         (void);
Index: libgnomedb/gnome-db-parameter.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-parameter.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-parameter.h
--- libgnomedb/gnome-db-parameter.h	29 Jul 2005 13:05:48 -0000	1.4
+++ libgnomedb/gnome-db-parameter.h	1 Dec 2005 18:24:14 -0000
@@ -53,7 +53,7 @@ struct _GnomeDbParameter
 /* struct for the object's class */
 struct _GnomeDbParameterClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 };
 
 GType                  gnome_db_parameter_get_type                (void);
Index: libgnomedb/gnome-db-qf-agg.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-qf-agg.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-qf-agg.h
--- libgnomedb/gnome-db-qf-agg.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-qf-agg.h	1 Dec 2005 18:24:14 -0000
@@ -56,7 +56,7 @@ struct _GnomeDbQfAgg
 /* struct for the object's class */
 struct _GnomeDbQfAggClass
 {
-	GnomeDbQfieldClass                  class;
+	GnomeDbQfieldClass                  parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbQfAgg *obj);
Index: libgnomedb/gnome-db-qf-all.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-qf-all.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-qf-all.h
--- libgnomedb/gnome-db-qf-all.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-qf-all.h	1 Dec 2005 18:24:14 -0000
@@ -55,7 +55,7 @@ struct _GnomeDbQfAll
 /* struct for the object's class */
 struct _GnomeDbQfAllClass
 {
-	GnomeDbQfieldClass                  class;
+	GnomeDbQfieldClass                  parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbQfAll *obj);
Index: libgnomedb/gnome-db-qf-field.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-qf-field.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-qf-field.h
--- libgnomedb/gnome-db-qf-field.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-qf-field.h	1 Dec 2005 18:24:14 -0000
@@ -55,7 +55,7 @@ struct _GnomeDbQfField
 /* struct for the object's class */
 struct _GnomeDbQfFieldClass
 {
-	GnomeDbQfieldClass                  class;
+	GnomeDbQfieldClass                  parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbQfField *obj);
Index: libgnomedb/gnome-db-qf-func.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-qf-func.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-qf-func.h
--- libgnomedb/gnome-db-qf-func.h	29 Jul 2005 13:05:48 -0000	1.4
+++ libgnomedb/gnome-db-qf-func.h	1 Dec 2005 18:24:14 -0000
@@ -56,7 +56,7 @@ struct _GnomeDbQfFunc
 /* struct for the object's class */
 struct _GnomeDbQfFuncClass
 {
-	GnomeDbQfieldClass                  class;
+	GnomeDbQfieldClass                  parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbQfFunc *obj);
Index: libgnomedb/gnome-db-qf-value.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-qf-value.h,v
retrieving revision 1.6
diff -u -p -r1.6 gnome-db-qf-value.h
--- libgnomedb/gnome-db-qf-value.h	29 Jul 2005 13:05:48 -0000	1.6
+++ libgnomedb/gnome-db-qf-value.h	1 Dec 2005 18:24:14 -0000
@@ -59,7 +59,7 @@ struct _GnomeDbQfValue
 /* struct for the object's class */
 struct _GnomeDbQfValueClass
 {
-	GnomeDbQfieldClass                  class;
+	GnomeDbQfieldClass                  parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbQfValue *obj);
Index: libgnomedb/gnome-db-qfield.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-qfield.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-qfield.h
--- libgnomedb/gnome-db-qfield.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-qfield.h	1 Dec 2005 18:24:14 -0000
@@ -64,7 +64,7 @@ struct _GnomeDbQfield
 /* struct for the object's class */
 struct _GnomeDbQfieldClass
 {
-	GnomeDbBaseClass            class;
+	GnomeDbBaseClass            parent_class;
 
 	/* pure virtual functions */
 	GObject          *(*copy)           (GnomeDbQfield *orig);
Index: libgnomedb/gnome-db-query.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-query.h,v
retrieving revision 1.5
diff -u -p -r1.5 gnome-db-query.h
--- libgnomedb/gnome-db-query.h	29 Jul 2005 13:05:48 -0000	1.5
+++ libgnomedb/gnome-db-query.h	1 Dec 2005 18:24:14 -0000
@@ -81,7 +81,7 @@ struct _GnomeDbQuery
 /* struct for the object's class */
 struct _GnomeDbQueryClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*type_changed)         (GnomeDbQuery *query);
Index: libgnomedb/gnome-db-ref-base.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-ref-base.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-ref-base.h
--- libgnomedb/gnome-db-ref-base.h	29 Jul 2005 13:05:48 -0000	1.3
+++ libgnomedb/gnome-db-ref-base.h	1 Dec 2005 18:24:14 -0000
@@ -63,7 +63,7 @@ struct _GnomeDbRefBase
 /* struct for the object's class */
 struct _GnomeDbRefBaseClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*ref_found)           (GnomeDbRefBase *obj);
Index: libgnomedb/gnome-db-result-set.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-result-set.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-result-set.h
--- libgnomedb/gnome-db-result-set.h	29 Jul 2005 13:05:49 -0000	1.4
+++ libgnomedb/gnome-db-result-set.h	1 Dec 2005 18:24:14 -0000
@@ -55,7 +55,7 @@ struct _GnomeDbResultSet
 /* struct for the object's class */
 struct _GnomeDbResultSetClass
 {
-	GnomeDbBaseClass             class;
+	GnomeDbBaseClass             parent_class;
 };
 
 GType           gnome_db_result_set_get_type           (void);
Index: libgnomedb/gnome-db-server-aggregate.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-server-aggregate.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-server-aggregate.h
--- libgnomedb/gnome-db-server-aggregate.h	6 Aug 2005 12:58:16 -0000	1.4
+++ libgnomedb/gnome-db-server-aggregate.h	1 Dec 2005 18:24:14 -0000
@@ -53,7 +53,7 @@ struct _GnomeDbServerAggregate
 /* struct for the object's class */
 struct _GnomeDbServerAggregateClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbServerAggregate *obj);
Index: libgnomedb/gnome-db-server-data-type.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-server-data-type.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-server-data-type.h
--- libgnomedb/gnome-db-server-data-type.h	29 Jul 2005 13:05:49 -0000	1.4
+++ libgnomedb/gnome-db-server-data-type.h	1 Dec 2005 18:24:14 -0000
@@ -54,7 +54,7 @@ struct _GnomeDbServerDataType
 /* struct for the object's class */
 struct _GnomeDbServerDataTypeClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbServerDataType *obj);
Index: libgnomedb/gnome-db-server-function.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-server-function.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-server-function.h
--- libgnomedb/gnome-db-server-function.h	6 Aug 2005 12:58:16 -0000	1.4
+++ libgnomedb/gnome-db-server-function.h	1 Dec 2005 18:24:14 -0000
@@ -53,7 +53,7 @@ struct _GnomeDbServerFunction
 /* struct for the object's class */
 struct _GnomeDbServerFunctionClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbServerFunction *obj);
Index: libgnomedb/gnome-db-server.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-server.h,v
retrieving revision 1.7
diff -u -p -r1.7 gnome-db-server.h
--- libgnomedb/gnome-db-server.h	11 Aug 2005 13:30:31 -0000	1.7
+++ libgnomedb/gnome-db-server.h	1 Dec 2005 18:24:16 -0000
@@ -110,7 +110,7 @@ struct _GnomeDbServer
 /* struct for the object's class */
 struct _GnomeDbServerClass
 {
-	GdaClientClass class;
+	GdaClientClass parent_class;
 
 	/* signals */
 	void   (*conn_opened)               (GnomeDbServer *obj);
@@ -168,7 +168,7 @@ GSList                 *gnome_db_server_
 GnomeDbUser            *gnome_db_server_get_user_by_name          (GnomeDbServer *srv, const gchar *username);
 
 GSList                 *gnome_db_server_get_data_types            (GnomeDbServer *srv);
-GnomeDbServerDataType  *gnome_db_server_get_data_type_by_name     (GnomeDbServer *srv, const gchar *typename);
+GnomeDbServerDataType  *gnome_db_server_get_data_type_by_name     (GnomeDbServer *srv, const gchar *type_name);
 GnomeDbServerDataType  *gnome_db_server_get_data_type_by_xml_id   (GnomeDbServer *srv, const gchar *xml_id);
 gboolean                gnome_db_server_declare_custom_data_type  (GnomeDbServer *srv, GnomeDbServerDataType *type);
 
Index: libgnomedb/gnome-db-table-field.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-table-field.h,v
retrieving revision 1.4
diff -u -p -r1.4 gnome-db-table-field.h
--- libgnomedb/gnome-db-table-field.h	29 Jul 2005 13:05:49 -0000	1.4
+++ libgnomedb/gnome-db-table-field.h	1 Dec 2005 18:24:16 -0000
@@ -54,7 +54,7 @@ struct _GnomeDbTableField
 /* struct for the object's class */
 struct _GnomeDbTableFieldClass
 {
-	GnomeDbBaseClass             class;
+	GnomeDbBaseClass             parent_class;
 };
 
 typedef enum {
Index: libgnomedb/gnome-db-table.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-table.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-table.h
--- libgnomedb/gnome-db-table.h	29 Jul 2005 13:05:49 -0000	1.3
+++ libgnomedb/gnome-db-table.h	1 Dec 2005 18:24:16 -0000
@@ -56,7 +56,7 @@ struct _GnomeDbTable
 /* struct for the object's class */
 struct _GnomeDbTableClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 
 	/* signals */
 	void   (*templ_signal)        (GnomeDbTable *obj);
Index: libgnomedb/gnome-db-target.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-target.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-target.h
--- libgnomedb/gnome-db-target.h	29 Jul 2005 13:05:49 -0000	1.3
+++ libgnomedb/gnome-db-target.h	1 Dec 2005 18:24:16 -0000
@@ -79,7 +79,7 @@ struct _GnomeDbTarget
 /* struct for the object's class */
 struct _GnomeDbTargetClass
 {
-	GnomeDbBaseClass                    class;
+	GnomeDbBaseClass                    parent_class;
 };
 
 GType           gnome_db_target_get_type               (void);
Index: libgnomedb/gnome-db-wrapper-field.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-wrapper-field.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-wrapper-field.h
--- libgnomedb/gnome-db-wrapper-field.h	29 Jul 2005 13:05:49 -0000	1.3
+++ libgnomedb/gnome-db-wrapper-field.h	1 Dec 2005 18:24:16 -0000
@@ -52,7 +52,7 @@ struct _GnomeDbWrapperField
 /* struct for the object's class */
 struct _GnomeDbWrapperFieldClass
 {
-	GnomeDbBaseClass            class;
+	GnomeDbBaseClass            parent_class;
 };
 
 GType             gnome_db_wrapper_field_get_type        (void);
Index: libgnomedb/graph/gnome-db-graph-item.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/graph/gnome-db-graph-item.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-graph-item.h
--- libgnomedb/graph/gnome-db-graph-item.h	29 Jul 2005 13:05:49 -0000	1.3
+++ libgnomedb/graph/gnome-db-graph-item.h	1 Dec 2005 18:24:16 -0000
@@ -54,7 +54,7 @@ struct _GnomeDbGraphItem
 /* struct for the object's class */
 struct _GnomeDbGraphItemClass
 {
-	GnomeDbBaseClass   class;
+	GnomeDbBaseClass   parent_class;
 	
 	/* signals */
 	void        (*moved) (GnomeDbGraphItem *item);
Index: libgnomedb/graph/gnome-db-graph-query.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/graph/gnome-db-graph-query.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-graph-query.h
--- libgnomedb/graph/gnome-db-graph-query.h	29 Jul 2005 13:05:49 -0000	1.3
+++ libgnomedb/graph/gnome-db-graph-query.h	1 Dec 2005 18:24:16 -0000
@@ -46,7 +46,7 @@ struct _GnomeDbGraphQuery
 /* struct for the object's class */
 struct _GnomeDbGraphQueryClass
 {
-	GnomeDbGraphClass   class;
+	GnomeDbGraphClass   parent_class;
 };
 
 GType            gnome_db_graph_query_get_type            (void);
Index: libgnomedb/graph/gnome-db-graph.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/graph/gnome-db-graph.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-graph.h
--- libgnomedb/graph/gnome-db-graph.h	29 Jul 2005 13:05:50 -0000	1.3
+++ libgnomedb/graph/gnome-db-graph.h	1 Dec 2005 18:24:16 -0000
@@ -53,7 +53,7 @@ struct _GnomeDbGraph
 /* struct for the object's class */
 struct _GnomeDbGraphClass
 {
-	GnomeDbBaseClass   class;
+	GnomeDbBaseClass   parent_class;
 	
 	/* signals */
 	void        (*item_added)   (GnomeDbGraph *graph, GnomeDbGraphItem *item);
Index: libgnomedb/handlers/gnome-db-data-cell-renderer-info.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/handlers/gnome-db-data-cell-renderer-info.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-data-cell-renderer-info.h
--- libgnomedb/handlers/gnome-db-data-cell-renderer-info.h	29 Jul 2005 13:05:50 -0000	1.3
+++ libgnomedb/handlers/gnome-db-data-cell-renderer-info.h	1 Dec 2005 18:24:16 -0000
@@ -39,6 +39,11 @@ extern "C" {
 #define IS_GNOME_DB_DATA_CELL_RENDERER_INFO_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO))
 #define GNOME_DB_DATA_CELL_RENDERER_INFO_GET_CLASS(obj)         (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_DB_TYPE_DATA_CELL_RENDERER_INFO, GnomeDbDataCellRendererInfoClass))
 
+enum _GnomeDbDataCellRendererInfoStatus
+{
+  GNOME_DB_DATA_CELL_RENDERER_INFO_STATUS
+};
+
 typedef struct _GnomeDbDataCellRendererInfo GnomeDbDataCellRendererInfo;
 typedef struct _GnomeDbDataCellRendererInfoClass GnomeDbDataCellRendererInfoClass;
 typedef struct _GnomeDbDataCellRendererInfoPriv GnomeDbDataCellRendererInfoPriv;
Index: libgnomedb/handlers/gnome-db-entry-boolean.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/handlers/gnome-db-entry-boolean.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-entry-boolean.h
--- libgnomedb/handlers/gnome-db-entry-boolean.h	29 Jul 2005 13:05:50 -0000	1.3
+++ libgnomedb/handlers/gnome-db-entry-boolean.h	1 Dec 2005 18:24:16 -0000
@@ -47,7 +47,7 @@ struct _GnomeDbEntryBoolean
 /* struct for the object's class */
 struct _GnomeDbEntryBooleanClass
 {
-	GnomeDbEntryWrapperClass         class;
+	GnomeDbEntryWrapperClass         parent_class;
 };
 
 GType        gnome_db_entry_boolean_get_type        (void);
Index: libgnomedb/handlers/gnome-db-entry-none.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/handlers/gnome-db-entry-none.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-entry-none.h
--- libgnomedb/handlers/gnome-db-entry-none.h	29 Jul 2005 13:05:50 -0000	1.3
+++ libgnomedb/handlers/gnome-db-entry-none.h	1 Dec 2005 18:24:16 -0000
@@ -47,7 +47,7 @@ struct _GnomeDbEntryNone
 /* struct for the object's class */
 struct _GnomeDbEntryNoneClass
 {
-	GnomeDbEntryWrapperClass         class;
+	GnomeDbEntryWrapperClass         parent_class;
 };
 
 GType        gnome_db_entry_none_get_type        (void);
Index: libgnomedb/handlers/gnome-db-entry-string.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/handlers/gnome-db-entry-string.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-entry-string.h
--- libgnomedb/handlers/gnome-db-entry-string.h	29 Jul 2005 13:05:50 -0000	1.3
+++ libgnomedb/handlers/gnome-db-entry-string.h	1 Dec 2005 18:24:16 -0000
@@ -47,7 +47,7 @@ struct _GnomeDbEntryString
 /* struct for the object's class */
 struct _GnomeDbEntryStringClass
 {
-	GnomeDbEntryWrapperClass         class;
+	GnomeDbEntryWrapperClass         parent_class;
 };
 
 GType        gnome_db_entry_string_get_type        (void);
Index: libgnomedb/handlers/gnome-db-entry-time.h
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/handlers/gnome-db-entry-time.h,v
retrieving revision 1.3
diff -u -p -r1.3 gnome-db-entry-time.h
--- libgnomedb/handlers/gnome-db-entry-time.h	29 Jul 2005 13:05:50 -0000	1.3
+++ libgnomedb/handlers/gnome-db-entry-time.h	1 Dec 2005 18:24:16 -0000
@@ -47,7 +47,7 @@ struct _GnomeDbEntryTime
 /* struct for the object's class */
 struct _GnomeDbEntryTimeClass
 {
-	GnomeDbEntryWrapperClass         class;
+	GnomeDbEntryWrapperClass         parent_class;
 };
 
 GType        gnome_db_entry_time_get_type        (void);

Attachment: signature.asc
Description: This is a digitally signed message part



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
Index: libgnomedb/gnome-db-server.c
===================================================================
RCS file: /cvs/gnome/libgnomedb/libgnomedb/gnome-db-server.c,v
retrieving revision 1.16
diff -u -p -r1.16 gnome-db-server.c
--- libgnomedb/gnome-db-server.c	12 Aug 2005 11:55:04 -0000	1.16
+++ libgnomedb/gnome-db-server.c	1 Dec 2005 18:24:16 -0000
@@ -2449,27 +2449,27 @@ gnome_db_server_get_data_types (GnomeDbS
 /**
  * gnome_db_server_get_data_type_by_name
  * @srv: a #GnomeDbServer object
  * @typename: the name of the requested data type
  *
  * Find a data type from its DBMS name or from one of its synonyms if it has some.
  *
  * Returns: the data type or %NULL if it cannot be found
  */
 GnomeDbServerDataType  *
-gnome_db_server_get_data_type_by_name (GnomeDbServer *srv, const gchar *typename)
+gnome_db_server_get_data_type_by_name (GnomeDbServer *srv, const gchar *type_name)
 {
 	GSList *list;
 	GnomeDbServerDataType *datatype = NULL;
 
 	g_return_val_if_fail (srv && IS_GNOME_DB_SERVER (srv), NULL);
 	g_return_val_if_fail (srv->priv, NULL);
-	g_return_val_if_fail (typename && *typename, NULL);
+	g_return_val_if_fail (type_name && *type_name, NULL);
 	
 	/* compare the data types names */
 	list = srv->priv->data_types;
 	while (list && !datatype) {
 		if (!strcmp (gnome_db_server_data_type_get_sqlname (GNOME_DB_SERVER_DATA_TYPE (list->data)),
-			     typename))
+			     type_name))
 			datatype = GNOME_DB_SERVER_DATA_TYPE (list->data);
 		list = g_slist_next (list);
 	}
@@ -2479,7 +2479,7 @@ gnome_db_server_get_data_type_by_name (G
 	while (list && !datatype) {
 		GSList *synlist = gnome_db_server_data_type_get_synonyms (GNOME_DB_SERVER_DATA_TYPE (list->data));
 		while (synlist && !datatype) {
-			if (!strcmp ((gchar *) (synlist->data), typename))
+			if (!strcmp ((gchar *) (synlist->data), type_name))
 				datatype = GNOME_DB_SERVER_DATA_TYPE (list->data);
 			synlist = g_slist_next (synlist);
 		}
@@ -2449,27 +2449,27 @@ gnome_db_server_get_data_types (GnomeDbS
  * gnome_db_server_get_data_type_by_name
  * @srv: a #GnomeDbServer object
- * @typename: the name of the requested data type
+ * @type_name: the name of the requested data type
  *
  * Find a data type from its DBMS name or from one of its synonyms if it has some.